// src/index.tsx
import {
  createClient
} from "@wix/sdk";
import * as React from "react";
import { createContext, useEffect, useMemo } from "react";
export * from "@wix/sdk";
var WixContext = createContext(void 0);
var HostEnvironmentContext = createContext(void 0);
function WixProvider(props) {
  const { children, auth, modules, host } = props;
  const client = useMemo(
    () => createClient({
      auth,
      modules,
      host
    }),
    [auth, modules, host]
  );
  return /* @__PURE__ */ React.createElement(WixContext.Provider, { value: client }, host ? /* @__PURE__ */ React.createElement(HostEnvironmentProvider, { host }, children) : children);
}
function HostEnvironmentProvider(props) {
  const [environment, setEnvironment] = React.useState(null);
  useEffect(() => {
    if (props.host.environment) {
      setEnvironment(props.host.environment);
    } else if (props.host.channel) {
      const handle = props.host.channel.observeState(
        (_, env) => setEnvironment(env)
      );
      return () => {
        Promise.resolve(handle).then((h) => h.disconnect());
      };
    }
  }, [props.host.environment, props.host.channel]);
  if (!environment) {
    return null;
  }
  return /* @__PURE__ */ React.createElement(HostEnvironmentContext.Provider, { value: environment }, props.children);
}
function useWix() {
  const sdk = React.useContext(WixContext);
  if (!sdk) {
    throw new Error(
      "SDK context not found. Make sure to render SDKProvider in the component tree"
    );
  }
  return sdk;
}
function useWixFetch() {
  const sdk = useWix();
  return sdk.fetch;
}
function useWixFetchWithAuth() {
  const sdk = useWix();
  return sdk.fetchWithAuth;
}
function useWixAuth() {
  const sdk = useWix();
  return sdk.auth;
}
function useWixModules(modules) {
  const sdk = useWix();
  return useMemo(() => sdk.use(modules), [sdk, modules]);
}
function useEnvironment() {
  const environment = React.useContext(HostEnvironmentContext);
  if (!environment) {
    throw new Error(
      "Host environment context not found. Make sure to render SDKProvider in the component tree and provide a host parameter"
    );
  }
  return environment;
}
export {
  WixProvider,
  useEnvironment,
  useWix,
  useWixAuth,
  useWixFetch,
  useWixFetchWithAuth,
  useWixModules
};
